## Что делать, если вы не знаете пароль (или входите через Госуслуги)

Если вы обычно входите в сервис «Мой налог» (lknpd.nalog.ru) через Госуслуги или просто не помните свой пароль (или просто не знаете), вам необходимо установить его в Личном Кабинете Налогоплательщика (ФЛ):

1.  Перейдите на сайт [lkfl2.nalog.ru](https://lkfl2.nalog.ru/).
2.  Авторизуйтесь удобным способом:
    *   Через **Госуслуги (ЕСИА)**.
    *   С помощью **электронной подписи (КЭП)**.
3.  Зайдите в **Настройки профиля** и установите (или смените) пароль для доступа к личному кабинету. (Даже если не знаете пароль)


!!! warning "Важно"
    Установленный таким образом пароль будет единым для входа в Личный Кабинет Физлица (lkfl2.nalog.ru) и в сервис «Мой налог» (lknpd.nalog.ru). Именно этот пароль нужно использовать в параметре `password` при инициализации `NpdClient`.

